Function libbzip3_sys::bz3_bound
source · pub unsafe extern "C" fn bz3_bound(input_size: usize) -> usizeExpand description
@brief Return the recommended size of the output buffer for the compression functions.
pub unsafe extern "C" fn bz3_bound(input_size: usize) -> usize@brief Return the recommended size of the output buffer for the compression functions.