pub unsafe extern "C" fn bz3_decompress(
    in_: *const u8,
    out: *mut u8,
    in_size: usize,
    out_size: *mut usize
) -> c_int
@brief Decompress a block of data. This function does not support parallelism by itself, consider using the low level bz3_decode_blocks() function instead. Using the low level API might provide better performance. Returns a bzip3 error code; BZ3_OK when the operation is successful. Make sure to set out_size to the size of the output buffer before the operation.