Function libbzip3_sys::bz3_encode_blocks
source · pub unsafe extern "C" fn bz3_encode_blocks(
states: *mut *mut bz3_state,
buffers: *mut *mut u8,
sizes: *mut i32,
n: i32
)Expand description
@brief Encode n' blocks, all in parallel. All specifics of the bz3_encode_block’ still hold. The function will launch a thread for each block.
The compressed sizes are written to the sizes' array. Every buffer is overwritten and none of them can overlap. Precisely n’ states, buffers and sizes must be supplied.
Expects `n’ between 2 and 16.
Present in the shared library only if -lpthread was present during building.