Function libbzip3_sys::bz3_free
source · pub unsafe extern "C" fn bz3_free(state: *mut bz3_state)Expand description
@brief Free the memory occupied by a block encoder state.
pub unsafe extern "C" fn bz3_free(state: *mut bz3_state)@brief Free the memory occupied by a block encoder state.