Function libbzip3_sys::bz3_last_error
source · pub unsafe extern "C" fn bz3_last_error(state: *mut bz3_state) -> i8Expand description
@brief Get the last error number associated with a given state.
pub unsafe extern "C" fn bz3_last_error(state: *mut bz3_state) -> i8@brief Get the last error number associated with a given state.