Function libbzip3_sys::bz3_strerror
source · pub unsafe extern "C" fn bz3_strerror(
state: *mut bz3_state
) -> *const c_charExpand description
@brief Return a user-readable message explaining the cause of the last error.
pub unsafe extern "C" fn bz3_strerror(
state: *mut bz3_state
) -> *const c_char@brief Return a user-readable message explaining the cause of the last error.