pub unsafe extern "C" fn bz3_decode_block(
state: *mut bz3_state,
buffer: *mut u8,
buffer_size: usize,
compressed_size: i32,
orig_size: i32,
) -> i32Expand description
@brief Decode a single block.
buffer' must be able to hold at least bz3_bound(orig_size)’ bytes
in order to ensure decompression will succeed for all possible bzip3 blocks.
In most (but not all) cases, orig_size should usually be sufficient.
If it is not sufficient, you must allocate a buffer of size bz3_bound(orig_size) temporarily.
If buffer_size is too small, BZ3_ERR_DATA_SIZE_TOO_SMALL will be returned.
The size must not exceed the block size associated with the state.
@param buffer_size The size of the buffer at ‘buffer’ @param compressed_size The size of the compressed data in ‘buffer’ @param orig_size The original size of the data before compression.