pub unsafe extern "C" fn bz3_decode_block(
    state: *mut bz3_state,
    buffer: *mut u8,
    size: i32,
    orig_size: i32
) -> i32
@brief Decode a single block. buffer' must be able to hold at least orig_size’ bytes. The size must not exceed the block size associated with the state. @param size The size of the compressed data in `buffer’ @param orig_size The original size of the data before compression.